function [activity] = FeedForwardDecayDemo(stim)
%Function to demonstrate how the branching ratio affects activity propagation in a layered feed-forward network.
%Can also provide some intuition about how much information is transmitted.

%A branching network with 100 neurons per layer, 10 outgoing connections/neuron and 100 layers is set up. 
%In the first layer, stim neurons are turned on and activity propagates via
%a branching process.The branching ratio, BR, is set for three values
%(subcritical, ~critical, supercritical). The network is run
%100 times and the average activity per layer is plotted for each network
%(subcritical (blue), ~critical (red), supercritical (green)).
%The average activity for each curve at layer 12 is printed out and
%returned through the variable activity. 

%Used in an exercise for Chapter 1 of the book.

%Set parameters
neurons = 100;
layers = 100;
connects = 10;
iterations = 100;
BR = 1.075;
delta = 0.5; 

%Check that stim has proper value
if stim < 0 | stim > 100
    error("Error: stim must be an integer from the interval 0 to 100")
end

%Run the network simulation for three branching ratios
figure; 
increment = [-delta, 0, +delta];
holder = zeros(length(increment), layers);
for i=1:3
    [Aavg, A] = FeedForwardActivity(stim, neurons, layers, connects, (BR + increment(i)), iterations);
    plot(Aavg); hold on
    holder(i,:) = Aavg;
end

%Label plot in linear scales
ylim([-1 100])
ylabel('Network activity', 'FontSize', 15); xlabel('Layer', 'FontSize', 15);

% %Plot results in loglog scales
% figure; 
% for i=1:length(increment)
%     loglog(holder(i,:)); hold on
% end
% %Label it
% ylabel('Network activity', 'FontSize', 15); xlabel('Layer', 'FontSize', 15);
% ylim([-1 70]);

%Deliver output
activity = holder(:, 12)  %Tells avg. number of active neurons at layer 12 in each network

