%ConwaysGOL
%lines 42-52 allow you to select different starting conditions. These variously
%show gliders, glider guns, etc. Comment out the conditions you don't want
%and uncomment the condition you do want. Runs on a 41 by 41 grid. For
%easiest viewing, click on the movie figure after it comes up to maximize it. 

clear all  %it is often good to clear variables for faster running

Neighbor = 1; %nearest neighbor connectivity if 1, non-nearest neighbor connectivity if 0. Note that density is calculated under assumption of nearest neighbor conditions, Not density assuming all possible connections
cD = 1;  %connection density if there4were nearest neighbor connections. If 1, then all possible connections within that distance will be there; if 0.5 then half, etc. 
mD = 1.5; %maximum distance a connection can span from reference site (cD = 1 is N,S,E,W nearest neighbors; cD = 1.5 is the eight nearest neighbors, etc.)
refperiod = 0;  %refractory period is zero here
UpperThresh = 3;   %neuron threshold. Note that in Conway's Game of Life, this should be 3
LowerThresh = 2;   %see below where the use of these two thresholds is described. Note that in Conway's Game of Life, this should be 2
p = 0.4;  %probability of neurons being on in the initial condition. Note that this is NOT probability of spontaneous activity at a single unit, as in previous script
PlayScrambledMovie = 0;  %1 if you want to play it, 0 if you don't
timesteps = 200; %can change this 
r=41; %dimensions of grid here
c=41;
WM = zeros(r*c, r*c);

%set up "weight matrix" which is really just a lattice of nearest neighbors
for i=1:r*c
    for j=1:r*c
        [x1, y1] = Linear2Cartesian(i,r);
        [x2 y2] = Linear2Cartesian(j,r);
        distance = sqrt((x2-x1)^2 + (y2-y1)^2);
        if  (distance <= mD) & (distance ~= 0)
            WM(i,j) = 1;
        end
    end
end


%initialize matrices
spont = sparse(r*c,1);  %random "membrane potentials" between 0 and 1 for each unit
act = sparse(r*c,1);  %gives driven activity at each unit, set by spont and connectivity matrix
current = sparse(r*c,1); %status of activity at current time step 
next = sparse(r*c,1);  %status of activity at next time step
TIMERASTER = sparse(r*c, timesteps);  %stores times of events for plotting later using LFPsorter routines

%determine initial starting condition
%holder = find(rand(r*c,1) < p); %for random starting condition
%holder = [2 24 43 44 45]; %one glider from upper left to lower right (for 21 by 21 array)
%holder = [2 24 43 44 45 379 380 381 402 422]; %two gliders collide and produce stationary squares (for 21 by 21 array)
%holder = [2 24 43 44 45 380 381 382 403 423]; %two gliders collide and produce stationary line
%holder = [2 24 43 44 45 381 382 383 404 424]; %two gliders collide and produce stationary line
%holder = [2 24 43 44 45 382 383 384 405 425]; %two gliders collide and produce a beehive
%holder = [2 24 43 44 45 383 384 385 406 426]; %two gliders collide and produce a stable fort with 12 units on
%holder = [2 24 43 44 45 384 385 386 407 427]; %two gliders narrowly miss each other (for 21 by 21 array)
holder = [47 48 88 89 457 458 459 497 501 537 543 578 584 622 661 665 703 704 705 745 ...
    865 866 867 906 907 908 946 950 1027 1028 1032 1033 1439 1440 1480 1481]; %glider gun for 41 by 41 array


spont(holder) = 1;
current = spont;  %current gives us which neurons are currently active

%march through time steps
for i=1:timesteps

   %determine units to be activated next time step by current activtiy that is over threshold
   act = WM * current;  %put into act the activity arriving at a neuron from its connected neighbors
   J = find(act == LowerThresh); %find all cases where this equals 2
   K = find(act == UpperThresh); %find all cases where this equals 3
   L = find(current == 1); %find all neurons currently on
   M = find(current == 0); %find all neurons currently off
   
   %Three cases for Conway's rules
   %I. Neuron is currently on and it is receiving 2 inputs. Then it should
   %continue to be on.
   A = sparse(r*c, 1); A(L) = 1;
   B = sparse(r*c, 1); B(J) = 1;
   case1 = A.*B;
   
   %II. Neuron is currently on and it is receiving 3 inputs. Then it should
   %continue to be on.
   A = sparse(r*c, 1); A(L) = 1;
   B = sparse(r*c, 1); B(K) = 1;
   case2 = A.*B;
   
   %III. Neuron is currently off and it is receiving 3 inputs. Then it
   %should turn on next time step. 
   A = sparse(r*c, 1); A(M) = 1;
   B = sparse(r*c, 1); B(K) = 1;
   case3 = A.*B;
   
   
   On = case1 + case2 + case3; %you can just add them because the three cases are disjunct (they will never have ones in the same spot, so you will never gat a 2 in the sum)
   act = sparse(r*c, 1);
   act = On;  
   
   
   %determine activity at next time step
   next = act;
   holder = find(next >= 1);
   next(holder) = 1;        %make next have binary values only
   holder = find(next < 1);
   next(holder) = 0;
   
      
   %update current matrix and clear other matricies
   current = next;
   next = sparse(r*c,1);
   act = sparse(r*c,1);
   TIMERASTER(:, i) = current;
   
end

%watch it
figure;
startind = 1; %this is the index of the first frame you will view
Holder = sum(TIMERASTER);
J = find(Holder);
framenum = length(J); %number of time steps you want to look at
frames = framenum;
axis equal
M = moviein(frames);
PMATRIX = [];
set(gca,'NextPlot','replacechildren')

for i=1:framenum
    spy4(reshape(10*TIMERASTER(:,J(i)), r, c)); 
    grid off
    M(:,i) = getframe;
    
end;

save NetMovie M TIMERASTER WM r c framenum J -mat

figure; spy2b(TIMERASTER, 'k.'); grid off;
ylabel('Neuron number', 'FontSize', 20); xlabel('Time steps', 'FontSize', 20);
ax = gca;
ax.FontSize = 20;
daspect([1 4 1]);

%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%
%plot sequence of frames from movie
figure;
greysB = [((1/64)*(64:-1:1))' ((1/64)*(64:-1:1))' ((1/64)*(64:-1:1))']; %black on top
%greysW = [((1/64)*(1:64))' ((1/64)*(1:64))' ((1/64)*(1:64))']; %white on top
chosenmap = greysB;
colormap(chosenmap)
frameStart = 1; %310; %569;
n = 5;
for i=1:n
    frame = reshape(TIMERASTER(:, frameStart+ ((30*(i-1)))), r, c); 
    subplot(1, n, i); imagesc(frame); %colormap(chosenmap); set(gca,'XTickLabel', ['']); set(gca,'YTickLabel', ['']); %set(gca,'XMinorTick', 'off'); set(gca,'YMinorTick', 'off'); %set(gca,'Visible', 'off');
    axis square;
    ax = gca;
    set(ax,'xticklabel',[])
    set(ax,'yticklabel',[])
%     ax.FontSize = 0.000001;
end  
%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%


%Scrambled movie
load NetMovie -mat
%code for scrambled movie
newOrder = randperm(r*c);
if PlayScrambledMovie == 1
    figure;
    for i=1:framenum
        spy4(reshape(10*TIMERASTER([newOrder],J(i)), r, c));
        grid off
        Mscrambled(:,i) = getframe;
    end
    
    %Plot raster from scrambled movie
    figure;
    spy2b(TIMERASTER(newOrder, :), 'k.'); grid off;
    ylabel('Neuron number', 'FontSize', 20); xlabel('Time steps', 'FontSize', 20);
    ax = gca;
    ax.FontSize = 20;
    daspect([1 4 1]);
    
    
    %plot same frame sequence from scrambled movie
    figure;
    greysB = [((1/64)*(64:-1:1))' ((1/64)*(64:-1:1))' ((1/64)*(64:-1:1))']; %black on top
    %greysW = [((1/64)*(1:64))' ((1/64)*(1:64))' ((1/64)*(1:64))']; %white on top
    chosenmap = greysB;
    colormap(chosenmap)
    frameStart = 230; %310; %569;
    n = 10;
    for i=1:n
        frame = reshape(TIMERASTER(newOrder, frameStart+i), 21, 21);
        subplot(1, n, i); imagesc(frame); %colormap(chosenmap); set(gca,'XTickLabel', ['']); set(gca,'YTickLabel', ['']); %set(gca,'XMinorTick', 'off'); set(gca,'YMinorTick', 'off'); %set(gca,'Visible', 'off');
        axis square;
        ax = gca;
        set(ax,'xticklabel',[])
        set(ax,'yticklabel',[])
%         ax = gca;
%         ax.FontSize = 0.000001;
    end
end

%Population vector analysis
offset = 20; %initial period 
PopVect = full(sum(TIMERASTER(:, offset:timesteps))/(r*c));

figure; plot(PopVect, 'k'); ylim([0 1]);
ylabel('Population activity', 'FontSize', 15); xlabel('Time steps', 'FontSize', 15);
ax = gca;
ax.FontSize = 15;
%daspect([1 4 1]);



