function [RuleUsed] = ModifiedLifeFunction(len, frames, rule)
%ModifiedLife - modified from Conway's Game of Life
%allows you to pick randomly a set of rules, then iterate them in 2D CA
%Code modified from something I found on the internet back in 2011. I
%cannot find the original source at this time, but it runs. Please let me
%know if you find the original source so I can give attribution. 
%Last updated 4 July 2022 JMB



% len = 100;    %edge size of grid
% frames = 350; %number of timesteps
%rule - if the number 0 is put in, the program will randomly select a rule.
%Otherwise, a saved rule can be input. To do this, take one of the saved
%rules, for example SimpleGliderRule, and load it into the Matlab
%workspace. Next, set that variable, in this case it will be called
%SimpleGliderRule, to equal rule, like this: rule = SimpleGliderRule;
%feed this as the input into the function. 

%%Initial conditions, some of which lead to structures in Conway's game of
%%life. That may not be the case if the rules are randomly selected. 
%GRID=int8(rand(len,len)); %if a random starting grid

GRID = zeros(len, len); %if zeros to be followed by a seed

%GRID(21,21:91)=1; GRID(34,25:95)=1;
GRID(20,20:21)=1;GRID(21,21)=1; GRID(19,26)=1; GRID(21,25:27)=1; GRID(19,26)=1; %activation of only a few cells

%C
%GRID(5,4:6)=1; 

%D
%GRID(5,4:6)=1;GRID(6,3:5)=1;

%E
%GRID(43,1:3)=1;GRID(42,3)=1;GRID(41,2)=1; %glider

%F
%GRID(5,5:8)=1;GRID(4,9)=1;GRID(3:4,5)=1; GRID(2,6)=1;GRID(2,9)=1;  %spaceship

% clear GRID
% GRID=int8(rand(len,len));

figure;

if rule == 0
    %randomly select a rule set. Note that the central cell and its 8 neighbors
    %are considered input. The central cell is the output.
    %A. Randomly pick a number from 1 to 512
    num = floor(rand*512) + 1;


    %B. Randomly select num of the 512 input configurations to lead to an
    %output of one in the central cell
    occupied = 1:512;
    for i=1:num
        pick = floor(rand*length(occupied)) + 1;
        if pick == 1
            occupied = occupied(2:end);
        else
            if pick == length(occupied)
                occupied = occupied(1:end-1);
            else
                occupied = [occupied(1:pick-1) occupied(pick+1:end)];
            end
        end
    end
    occupied;  %the rule is encoded in this variable
    RuleUsed = occupied;


else

    occupied = rule; 
    RuleUsed = rule;

end
    
up=[2:len 1]; down=[len 1:len-1]; %periodic boundary conditions

colormap(gray(2));
M = moviein(frames); 
% Prepare the new file.
vidObj = VideoWriter('LifeRuleMovie1.avi');
open(vidObj);
axis tight
set(gca,'nextplot','replacechildren');

for i=1:frames
    
    %read binary neighborhood of each cell and convert it to a number from
    %0 to 511
    vect = 256*GRID(:,:) + 128*GRID(up,up) + 64*GRID(up,:) + 32*GRID(up,down) + 16*GRID(:,down)...
        + 8*GRID(down,down) + 4*GRID(down,:) + 2*GRID(down,up) + GRID(:,up);
    
    %use the numbers to apply the rule chosen above
    GRID = ismember(vect, occupied);
 
    %display 
    image(GRID*2); axis('square'); pause(0.02); xlim([0 len]); ylim([0 len]); 
    M(:,i) = getframe;
    % Write each frame to the file.
    currFrame = getframe;
    writeVideo(vidObj,currFrame);
end

% Close the file.
close(vidObj);




