%NetworkModelCellularAutomaton
%Revision 1

clear all

% Set parameters here
Neighbor = 1; %nearest neighbor connectivity if 1, non-nearest neighbor connectivity if 0. Note that density is calculated under assumption of nearest neighbor conditions, Not density assuming all possible connections
cD = 1;  %connection density if there were nearest neighbor connections. If 1, then all possible connections within that distance will be there; if 0.5 then half, etc. 
mD = 3; %maximum distance a connection can span from reference site (cD = 1 is N,S,E,W nearest neighbors; cD = 1.5 is the eight nearest neighbors, etc.)
refperiod = 5;
Nthresh = 4;   %neuron threshold
p = 0.02;  %probability of spontaneous activity at a single unit
PlayScrambledMovie = 0;  %1 if you want to play it, 0 if you don't
timesteps = 200; %can be made much longer if you want to get better statistics
r=21; %number of rows in sheet of neurons
c=21; %number of columns in sheet of neurons
fps = 7; %fps is frames per second when replaying the movie

% Set up weight matrix (WM)
WM = zeros(r*c, r*c);
for i=1:r*c
    for j=1:r*c
        [x1, y1] = Linear2Cartesian(i,r);
        [x2 y2] = Linear2Cartesian(j,r);
        distance = sqrt((x2-x1)^2 + (y2-y1)^2);
        if  (distance <= mD) & (distance ~= 0)
            WM(i,j) = 1;
        end
    end
end

occupied = find(WM == 1);
WM(occupied) = 0;
occupiedScrambled = randperm(length(occupied));
endpoint = min(floor(length(occupied)* cD)+1 , length(occupied));
toKeep = occupiedScrambled(1:endpoint);
K = occupied(toKeep);
WM(K) = 1;

if Neighbor == 1 %if nearest neighbor coupling, just keep the connections you just calculated
    WM = WM;
    %figure; spy(WM);
else     %if not nearest neighbor coupling, just take connections from nearest neighbor and scramble them throughout the matrix so they have exactly the same density as in nearest neighbor case
    len = length(occupiedScrambled);
    sitesScrambled = randperm(r*c*r*c);
    K = sitesScrambled(1:len);
    WM = zeros(r*c, r*c);
    WM(K) = 1;
    %figure; spy(WM);
end
    
%initialize matrices
spont = sparse(r*c,1);  %random "membrane potentials" between 0 and 1 for each unit
ref = sparse(r*c,1);  %lists how many time steps each electrode will be refractory for
act = sparse(r*c,1);  %gives driven activity at each unit, set by spont and connectivity matrix
act2 = sparse(r*c,1);
current = sparse(r*c,1); %status of activity at current time step 
next = sparse(r*c,1);  %status of activity at next time step
WMA = sparse(r*c, r*c); %Weight matrix active (those weights chosen by chance to be "active" during that time step
TIMERASTER = sparse(r*c, timesteps);  %stores times of events for plotting later


%march through time steps
for i=1:timesteps

   %determine spontaneous activity over threshold
   holder = find(rand(r*c,1) < p);
   spont(holder) = 1;
      
   %determine units to be activated next time step by current activtiy that is over threshold
   J = find(rand(r*c, r*c) < WM); %first find connections that could be active
   WMA(J) = 1;
   act = WMA * current;  
   J = find(act >= Nthresh); 
   act = sparse(r*c, 1);
   act(J) = 1;
   
   
   
   %determine activity at next time step
   next = spont + act;
   holder = find(ref > 0);  %turn off all units that are already refractory
   next(holder) = 0;
   holder = find(current >= 1);
   next(holder) = 0;        %turn off all units in next time step that fired in current time step
   holder = find(next >= 1);
   next(holder) = 1;        %make next have binary values only
   holder = find(next < 1);
   next(holder) = 0;
   
   %determine refractory units for next time step
   ref = ref -1;  %decrement old values
   holder = find(ref < 0);
   ref(holder) = 0;
   holder = find(next >= 1);  %increment new values
   ref(holder) = refperiod;
      
   %update current matrix and clear other matricies
   current = next;
   next = sparse(r*c,1);
   act = sparse(r*c,1);
   spont = sparse(r*c,1);
   WMA = sparse(r*c, r*c);
   TIMERASTER(:, i) = current;
   
end

%watch it
figure;
startind = 1; %this is the index of the first frame you will view
Holder = sum(TIMERASTER);
J = find(Holder);

framenum = length(J); %number of time steps you want to look at
frames = framenum;
axis equal
M = moviein(frames);
PMATRIX = [];
set(gca,'NextPlot','replacechildren')

for i=1:framenum
    spy4(reshape(10*TIMERASTER(:,J(i)), r, c)); 
    grid off
    M(:,i) = getframe;
    
end

%Replay the movie at a slower pace
figure; axis('square'); movie(M, 1, fps); %fps is frames per second

save NetMovie M TIMERASTER WM K r c framenum J -mat


figure;
spy2(TIMERASTER, 'k.'); grid off; %was spy2b
ylabel('Neuron number', 'FontSize', 20); xlabel('Time steps', 'FontSize', 20);
ax = gca;
ax.FontSize = 20;
daspect([1 4 1]);

%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%
%plot sequence of frames from movie
figure;
greysB = [((1/64)*(64:-1:1))' ((1/64)*(64:-1:1))' ((1/64)*(64:-1:1))']; %black on top
chosenmap = greysB;
colormap(chosenmap)
frameStart = floor(timesteps/2); 
n = 10;
for i=1:n
    frame = reshape(TIMERASTER(:, frameStart+i), r, c); 
    subplot(1, n, i); imagesc(frame); 
    axis square;
    ax = gca;
    set(ax,'xticklabel',[])
    set(ax,'yticklabel',[])
%     ax.FontSize = 0.000001;
end  
%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%


%Scrambled movie
load NetMovie -mat
%code for scrambled movie
newOrder = randperm(r*c);
if PlayScrambledMovie == 1
    figure;
    for i=1:framenum
        spy4(reshape(10*TIMERASTER([newOrder],J(i)), r, c));
        grid off
        Mscrambled(:,i) = getframe;
    end
    
    %Plot raster from scrambled movie
    figure;
    spy2b(TIMERASTER(newOrder, :), 'k.'); grid off;
    ylabel('Neuron number', 'FontSize', 20); xlabel('Time steps', 'FontSize', 20);
    ax = gca;
    ax.FontSize = 20;
    daspect([1 4 1]);
    
    
    %plot same frame sequence from scrambled movie
    figure;
    greysB = [((1/64)*(64:-1:1))' ((1/64)*(64:-1:1))' ((1/64)*(64:-1:1))']; %black on top
    chosenmap = greysB;
    colormap(chosenmap)
    frameStart = floor(timesteps/2); 
    n = 10;
    for i=1:n
        frame = reshape(TIMERASTER(newOrder, frameStart+i), r, r);
        subplot(1, n, i); imagesc(frame); 
        axis square;
        ax = gca;
        set(ax,'xticklabel',[])
        set(ax,'yticklabel',[])
    end
end

%Population vector analysis
offset = 1; %initial period 
PopVect = full(sum(TIMERASTER)/(r*c));
figure; plot(PopVect, 'k'); ylim([0 1]);
ylabel('Population activity', 'FontSize', 15); xlabel('Time steps', 'FontSize', 15);
ax = gca;
ax.FontSize = 15;
%daspect([1 4 1]);
