function [A chi FR] = BrunelNetworkFunctionTimeConstant(gee, ratio, Jc)
% This function only has one stimulation event, unlike
% BrunelNetworkFunction, which has continuous background drive
% chi is the susceptibility, A is the curve of activity after the stim. It
% will either decay or grow exponentially. 

%BrunelNetworkSimulationModified3
% To test direct stimulation
% Simulation of the Brunel JCNS 2000 network with electrode recording
% spikes (Destexhe, Touboul - PRL Comment, 2020).
% (C) Touboul J.
% jonathan.touboul@gmail.com.
% Modified by John Beggs, August 2021

g= gee; %4.5 ; %4+4*(rand());                         % Strength of inh connections -gJ
ratioextthresh= ratio; %1;    %1.1+0.2*(rand()-0.5);    % nu_ext/nu_thresh
Jcoeff = Jc;
Duration=0.2;     % Total duration
N = 1000;         % Number of neurons
Nstim = 200; %was 100;    % Number of neurons stimulated
dt=0.1e-3;      % time-step
NTimes= ceil(Duration/dt);   % Number of time-steps, in units of dt
StimTime = 100; 
ExInput = zeros(N, NTimes);  %setting up stimulation
list = randperm(N);  %select random neurons to stimulate
ExInput(list(1:Nstim), StimTime) = 1;  %this is the stimulation: rows indicate which neurons, times are second dimension.


    


Spikes={};
if ~exist('N_iter')
    N_iter=1;
end

    
    
   
    
    
    %%%%%%%%   PARAMETERS OF THE NETWORK  %%%%%%%%
    
    NE=ceil(0.8*N);      % # excitatory neurons
    NI=N-NE;             % # excitatory neurons
    
    
    
    % (p.185, 2nd column, Brunel 2000)
    V_t=20e-3; % voltage threshold   20 mV
    V_r=10e-3; % voltage reset       10 mV
    tau=20e-3; % voltage time constant   20 ms
    t_rp=2e-3; % refractory period        2 ms
    
    
    
    %%%%%% BIFURCATION PARAMETERS in Brunel 2000 %%%%%%%
    
    J=0.12e-3;                  % Strength of exc. Connections
    J=J*10000/N;                % Rescaling to make behaviors independent of N
    
    Connectivity= 0.1;           % Connectivity coefficients, parameter epsilon in Brunel 2000. 0.1 = 10% of all possible connections
    D=1.8e-3;                        % Transmission Delay   1.8 ms
    CE=round(Connectivity*NE);          % Number of exc connections
    CI=round(Connectivity*NI);          % Number of inh connections
    C_ext= floor(1*CE);                           %number of connections from external source? Equal to number of excitatory connections? 
    
    
    nu_thresh=V_t/(J*CE*tau);   % Frequency needed for a neuron to reach the threshold.
    
    
    %%%%%%%%   SIMULATION PARAMETERS %%%%%%%%
    
    N_rp=round(t_rp/dt);        % Refractory (in dt)   20 time steps, where each step is 0.1 ms
    N_del=round(D/dt);          % delay (in dt)        18 time steps, where each step is 0.1 ms
    
    %See phase plot from T+D PRE paper 2017, figure 4. This shows the
    %phase - synchronous regular, asynchronous irregular, synchronous irregular -  
    %(SR, AI, SI) with respect to the parameters g and ratioextthresh. 
%     g= 4.5 ; %4+4*(rand());                         % Strength of inh/exc (inh connections -gJ)
%     ratioextthresh= 1;    %1.1+0.2*(rand()-0.5);    % nu_ext/nu_thresh
    nu_ext=ratioextthresh*nu_thresh;        % external Poisson input rate
    
    W=zeros(N,N);
    %Drive = zeros(NTimes, 1);
    
    %%%%%%%%   Generation of the connectivity matrix %%%%%%%%
    
    for i=1:N
        ECells=randperm(NE);
        ECells=ECells(1:CE);
        W(i,ECells)=J;
        
        ICells=randperm(NI);
        ICells=NE+ICells(1:CI);
        W(i,ICells)=-1;
    end
    
    for Iteration=1:N_iter
        %fprintf(sprintf('Iteration %d/%d\n',Iteration,N_iter))
        
        W(W<0)=-g*J;
        Rasterplot=zeros(N,NTimes);
        Rasterplot_pert=zeros(N,NTimes);
        
        V=V_r*ones(N,1);            % Voltage vector
        
        LS=-(N_del+1)*rand(N,1);
        
        allspikes=zeros(1,NTimes);
        
        
        hits = 0;
        i=0;
        %ExInput=J*poissrnd(nu_ext*C_ext*dt,N,NTimes);
        %     ExInput = zeros(N, NTimes);
        %     ExInput(501:1000, 100) = 1;
        while i<NTimes
            i=i+1;
            %         if i == 10
            % %             ExInput = zeros(N, NTimes);
            % %             ExInput(1:500, 1:2) = 1;
            %             ExInput=J*poissrnd(nu_ext*C_ext*dt,N,Ntimes);
            %         end
            
            %         if (1+mod(i-1,1e4))==1 & (hits <= 10000)  %this sets the random input rate every epoch of 1000 milliseconds. In 5 sec of simultated data, it changes 5 times.
            %             ExInput=J*poissrnd(nu_ext*C_ext*dt,N,1e4); %creates array where first number is rate, second numbers are dimensions
            %             %ExInput(1:500, :) = 0;  %trying to reduce drive to zero in half the neurons
            %         end
            %         if (1+mod(i-1,1e4))==1 & (hits > 10000)
            %             %ExInput = J*poissrnd(nu_ext*C_ext*dt,N,1e4);
            %             ExInput = J*Jcoeff*poissrnd(nu_ext*C_ext*dt,N,1e4); %if J multiplied by 0.333, it almost completely shuts it off
            %             %ExInput(1:500, :) = J*0.333*poissrnd(nu_ext*C_ext*dt,500,1e4);  %trying to reduce drive to zero in half the neurons
            %         end
            hits = hits + 1;
            %
            %Drive(i) = sum(ExInput(501,:)); %just use neuron 501 as a sample readout of activity
            
            V=(1-dt/tau)*V+ExInput(:,i)+W*Rasterplot(:,max(1,i-N_del));        % Voltage update
            
            spike=V>=V_t;               % Spiking neurons have a "1"
            V(LS>i-N_del)=V_r;          % Refractory period.
            
            
            LS(spike)=i;                % Time of last spike
            V(spike)=V_r;               % Reset membrane potential
            % Store spike times
            Rasterplot(:,i)=spike;      % Each row is (neuron number,spike time)
            allspikes(1,i)=sum(spike);
            
            %         progressbar(i,NTimes);
            
        end
        Spikes{Iteration}=allspikes;
        
    end
    
%     figure; spy2(Rasterplot)
%     figure; plot(Spikes{1})
    chi = var(Spikes{1});   %this is the susceptibility
    FR = sum(Spikes{1})/NTimes;   %this is the avg firing rate, FR
    %should get time constant tauDecay here
    A = zeros(49,1);
    for i=1:49
        A(i) = Spikes{1}(StimTime + ((i-1)*(D/dt)));
    end
    %figure; plot(A)
    
    
    
    %figure; plot(Drive);
    %figure; plot(sum(Rasterplot));
    % hits
    % figure; spy2(ExInput);
    
    
    % %Estimate entropy for present model
    % %Will sample Num neurons
    % Num = 4; %this will produce 2^Num states
    % beg = 100; %time step at which to start
    % fin = NTimes; %time step at which to end
    
    % TIMERASTER = sparse(Rasterplot);
    % %figure; spy2(TIMERASTER)
    %
    %
    %
    % [Events, Locations, IEI, Areas, Runtimes] = runstats2b(TIMERASTER);
    %
    % %routine to plot run length distributions from runstats
    % clear dist
    % for i=1:length(Events)
    %    durations(i) = length(Events{i});
    % end;
    %
    % for i=1:max(durations)
    %    dummy = find(durations == i);
    %    dist(i) = length(dummy);
    % end;
    % % F = find(dist < 1000);
    % % chosenrunlength = F(1);
    % y = 1:length(dist);
    % figure; plot(log10(y),log10(dist/sum(dist)),'k o'); ylabel('Log(Prob(Avalanche duration))', 'FontSize', 15); xlabel('Log(Avalanche duration)', 'FontSize', 15);
    % lengthdist = [y; dist];
    %
    % %line([0.301 1.491], [-0.2775 -2.191])
    % %line([0.301 1.748], [-0.3598 -2.4666])
    %
    % %routine to plot area distributions from runstats
    % clear dist
    % dist = sparse(1, max(Areas));
    % for i=1:max(Areas)
    %    dummy = find(Areas == i);
    %    dist(i) = length(dummy);
    % end;
    % x = 1:max(Areas);
    %
    % figure;
    % plot(log10(x),log10(dist/sum(dist)),'k o'); ylabel('Log(Prob(Avalanche size))', 'FontSize', 15); xlabel('Log(Avalanche size)', 'FontSize', 15);
    % areadist = [x; dist];
    %
    % %Plot S vs T
    % for i=1:max(durations)
    %     dummy = find(durations == i);
    %     AvgArea(i) = sum(Areas(dummy))/length(dummy);
    % end
    % figure;
    % plot(log10(y), log10(AvgArea),'k o');
    % ylabel('Log10(Avg. Avalanche size)', 'FontSize', 15); xlabel('Log10(Avalanche duration)', 'FontSize', 15);
    % %axis square
