%BrunelTimeConstantFinal 
%Uses Brunel model code adapted from Destexhe and Touboul, 2021. 
%Runs Brunel model for several different values of g, the relative strength
%of inhibitory coupling. Stimulation is delivered at time step 100 and background 
%drive is turned to zero. Records average level of activity as well as time
%constants of response to stimuli. Plots response to stimuli for each value
%of g. Plots time constants against g, should show a peak near g = 3 or g =
%3.5


ratio = 1.0; %1; %nu_inhib/nu_excit from Brunel's paper in 2000
Jc = 1; %1; %base level of excitatory neuron connections
reps = 30; %number of times a network with a given set of parameters is instantiated
steps = 20; %number of increments of g in plotting the phase transition
A_all = zeros(reps, 49);
FR_all = zeros(steps, 1);
G = zeros(steps, 1);
DecayConstant = zeros(steps, 1); 
for j=1:steps
    holderFR = 0;
    gee = (j-1)*0.25; 
    G(j) = gee;
    for i = 1:reps
        i
        [A chi FR] = BrunelNetworkFunctionTimeConstantFinal(gee, ratio, Jc);
        A_all(i, :) = A;
        %Do curve fitting on A to get time constant
        holderFR = holderFR + FR;
    end
    
    FR_all(j) = holderFR/reps;
    
    figure; plot(mean(A_all)); hold on;  ylabel('Activity', 'FontSize', 15); xlabel('time steps', 'FontSize', 15);
    plot(mean(A_all) + std(A_all), 'c');
    plot(mean(A_all) - std(A_all), 'c');
    
    %Curve fit for A_all
    holder = 3:40;
    x = holder';
    clear holder
    holder = mean(A_all);
    y = holder(3:40)'; 
    gu = fittype('a-b*exp(-c*x)');
    f0 = fit(x,y,gu,'StartPoint',[[ones(size(x)), -exp(-x)]\y; 1]);
    xx = linspace(3,40,50);
    plot(x,y,'o',xx,f0(xx),'r-');
    DecayConstant(j) = 1/f0.c;
    hold off
    
end

figure; plot(G, FR_all); ylabel('Firing rate', 'FontSize', 15); xlabel('g', 'FontSize', 15);
figure; plot(G, DecayConstant, 'o'); ylabel('Decay constant', 'FontSize', 15); xlabel('g', 'FontSize', 15);

