function [JRASTER] = JitterRaster(RASTER, sigma)
%Takes a RASTER (which may contain amplitude or binary values) and jitters the time
%of each event by a random number of bins drawn from a normal distribution with standard deviation sigma.
%Note: some loss of events may take place here, since two events may be jittered into the same space, but this should be rare
%The jittered raster is returned as JRASTER.


[r c] = size(RASTER); %get size: rows, columns
[e f a] = find(RASTER); %find active locations
J = round(sigma * randn(length(f), 1)); %get vector of jitter values drawn from normal distribution with standard devaition sigma
Jf = f + J; %add jittered values to spike times
Jf(find(Jf <= 0)) = 1; %take care of boundary cases at beginning
Jf(find(Jf > c)) = c;  %take care of boundary cases at end
JRASTER = sparse(e, Jf, a, r, c); %re-assemble it



