function [BR BRnaive] = branchingEstimate(TR)
%estimates branching ratio for a TIMERASTER, TR
%BR output is the branching ratio estimated using multiple regression
%method developed by (Wilting and Priesemann, 2018 Nature Communications)
%and (Spitzner et al., 2021 PLoS One). This method is unbiased. 
%BRnaive is the simplistic method first used by (Beggs and Plenz, 2003). It
%merely takes a ratio of the average descendants/average ancestors. This
%method is biased. 


% k_max is the number of points for the polynomial fit for  Wilting and Priesemann's 
% algorithm. The larger the better.
k_max = 200; %1000;
% Compress the raster data into one vector
Act = sum(TR,1);


% Naive BR calculation
At = Act(1:(end-1));
At1 = Act(2:end);
% Get coefficients assuming linear relationship between activities
Coeffs = polyfit(At,At1,1);
BRnaive = Coeffs(1); %just the first term; naively

% Priesemann & Wilting Method for BR calculation
delayrange=1:k_max;
slopevals = zeros([1,length(delayrange)]);
for ik = 1:length(delayrange)
    
    At = Act(1:(end - delayrange(ik)));
    Atk = Act((1 + delayrange(ik)):end);
    Coeffs = polyfit(At,Atk,1);
    slopevals(ik) = Coeffs(1);
    
end

% The exponential fit
function F = expfit(x,xdata)
F = x(2)*(x(1).^(xdata));

end

% Perform the exponential fit on the slopes
x0 = [1,1];
[ExpCoeffs,resnorm] = lsqcurvefit(@expfit,x0,delayrange,slopevals);

BR = ExpCoeffs(1);

end

