function [TR2] = rebinRaster(TR, binWidth)
%Function to rebin original TIMERASTERs, which typically have a bin width
%of 1 ms, into larger bins. For example, if binWidth = 6, then the data
%will be given in time bins of 6 ms. If there is more than one spike/LFP in
%the new 6 ms bin, it will just be merged to one event. 

%get size, preallocate TIMERASTER2
[r c] = size(TR);
TR2 = sparse(r, floor(c/binWidth));

%find active neurons/channels (I) and times (J) of spikes in TIMERASTER
[I J S] = find(TR);

%make sure that S will only have one event (spike/LFP) per entry
[K] = find(S);
S(K) = 1; %set them all to 1

%create new rebinned times
NewTimes = floor((J/binWidth) + (1/binWidth) + 1);

%load spikes into TIMERASTER2 with new times, same neurons/channels
TR2 = sparse(I, NewTimes, S, r, floor(c/binWidth)+1); 






