function [TIMERASTER] = FeedForwardBranchingModelFunction(neurons, numStim, layers, connects, BR, timesteps)
%Here we will only activate one neuron in the first
%layer and watch how it causes activity to propagate. 
%Once activated, it runs until the avalanche stops, then
%waits one blank frame before initiating again. Will run until TIMERASTER
%is exceeded, then it will stop.
%uses weights2

%Explanation of input parameters and representative sample values
%neurons = 50; %number of neurons in each layer
%numStim = 1; %number of neurons to be stimulated in first layer
%layers = 25;  %number of layers in the feedforward network
%connects = 5; %number of connections each neuron projects into the next layer
%BR = 1.2;     %the Branching Ratio by construction
%timesteps = 500; %number of timesteps the network is run for in producing the TIMERASTER


%Transfer input variables to match text below
c = neurons;
r = layers; 
sums = BR; 

%Set initializations
activity = sparse(r, c);  %binary activity of r*c units, initialized to zeros
TIMERASTER = sparse(c, timesteps); 
%c is the number of input units in the network, and r is the number of rows
%from the network to be taken as the output. 
 

%Set up random connectivity and random synaptic weights
for i=1:r   %for each layer
   for j=1:c  %for each unit in the layer
      holder = [];
      for k=1:connects
         holder = [holder floor(rand*c)+1];
      end
      conmat{i,j} = holder; %conmat{i,j} gives units in next layer getting projections from unit{i,j}
      weightmat{i,j} = weights2(connects, sums)'; %weights of connections from unit{i,j} 
   end
end


   %now that connectivity and weights are "frozen," propagate activity through the network many times
   for m=1:timesteps
      activity = sparse(r, c);
      %propagate activity through network
      %propagate input to first layer
      ChosenOne = randperm(c);
      activity(1,ChosenOne(1)) = 1;   %pick only one neuron to be active at start
      
      %propagate from first layer to all subsequent layers
       for i=1:r-1
         for j=1:c
            for k=1:connects
               if (rand <= weightmat{i,j}(k)) && (activity(i,j) ~= 0)
                  activity(i+1,conmat{i,j}(k)) = 1;
               end
            end
         end
       end
       
       %now take activity from r rows of the network and place it
       %in TIMERASTER 
       TIMERASTER(:, m) = activity(r,:)'; %only put in the last row, after activity propagated for r layers
   end
   

