function [TotalMI, Hresp, Hcond, BRs] = RecurrentInfoFunction(N, r, c, connects, reps, timesteps, increments, increment, numNets)
%Recurrent branching network, has a sheet of neurons of size r x c.
%Stimulates at time 1, then lets activity propagate for timesteps times.
%Runs for different branching ratios, which start at 0.1 and increase by
%increment for increments times. Each stimulus is given reps times, and
%numNets networks are instantiated and run. 
%Uses RecurrentInfoTester and FindInformation. Provides Hresp and Hcond along with the info. 


%Explain parameters and give examples
% N = 6; %Number of input and output units you will sample from to calculate Mutual Information 
% r = 4; %rows of neurons
% c = 4; %columns of neurons; total sheet of neurons is r * c total neurons
% connects = 6; %number of connections coming out of each neuron, projecting to other neurons
% reps = 100; %number of times you want to run activity through each network. It is good to do this many times to reduce noise
% timesteps = 15; %how many timesteps the activity will propagate through the recurrent network
% increments = 21; %this is how many increments you want to have in your sweep of the branching ratio
% increment = 0.2; %The amount by which the branching ratio is incremented each time 
% numNets = 2; %number of networks you want to instantiate. Good to have many to reduce noise, take average

%Prepare arrays
TotalMI = zeros(timesteps, increments, numNets);
TotalMIavg = zeros(timesteps, increments);
Hresp = zeros(timesteps, increments, numNets);
Hcond = zeros(timesteps, increments, numNets);
BR_Start = 0.1;  %first branching ratio
BRs = [BR_Start:increment:increment*increments]; %branching ratios used

for num=1:numNets %number of different network instantiations you want to do
    for i=1:increments  %this is how many increments you want to have in your sweep of the branching ratio
        i
        num
        sigma = BR_Start + (i-1)*increment;
        [stim, resp] = RecurrentInfoTester(r, c, connects, sigma, reps, timesteps, N);
        for j=1:timesteps %get MI for each timestep j. 
            [A B C] = FindInformation(stim(j, :), resp(j, :), N);
            TotalMI(j,i, num) = A;
            Hresp(j,i,num) = B;
            Hcond(j,i,num) = C;
        end
    end 
end

