function [TIMERASTER] = RecurrentModel(input, inputconfig, connects, connmat, weightmat, timesteps, InputUnits, OutputUnits)
%Recurrent branching model propagates activity over time. 

%This version allows timesteps to be specified.
%note also that inputconfig can also be specified. this is the
%configuration of all the "background" units of the network that are not
%chosen as InputUnits or OutputUnits. This inputconfig should be random,
%50% ones and 50% zeros, and kept the same each time the network is run.
%This way, the program is examining how a random subset of neurons can
%transmit information to another random subset of neurons in a background
%of noise. 




%timesteps = 3;  %number of time steps. 
%initial parameters
%r = 8;  %rows    dimensions of "electrode grid" rows X columns. If 8 X 8, then 64 electrodes.
%c = 8;  %columns


threshold = 1; %1 - p;  %when membrane potential at a unit is over this, it becomes active for 1 time step
alpha = 1.0; 		%fraction of activity that is transmitted
refperiod = 0;  %number of time steps that unit is refractory after firing
%connects = 2;  %number of connections that each unit makes to other units
%sums = 1.0;   %total sum of synaptic weights



%initialize matrices
[r, c] = size(inputconfig);
ref = sparse(r,c);  %lists how many time steps each electrode will be refractory for
act = sparse(r,c);  %gives driven activity at each unit, set by spont and connectivity matrix
current = inputconfig; %status of activity at current time step
current(InputUnits) = input;
next = sparse(r,c);  %status of activity at next time step
TIMERASTER = sparse(length(InputUnits), timesteps);  %stores times of events for plotting later using LFPsorter routines

%march through time steps
for i=1:timesteps
         
   %determine units to be activated next time step by current activtiy that is over threshold
   for j=1:r*c
      if current(j) ~= 0 %If unit j is active, it may transmit to other units 
         for k=1:connects 
             if rand < weightmat{j}(k) %the synapse has a probability of transmission
                 act(connmat{j}(k)) = act(connmat{j}(k)) + (alpha * 1);  %if it transmits, then update act matrix
             end
         end
      end
   end   
   holder = find(act >= threshold);  %trim act to keep it from accumulating large values
   act(holder) = 1;
      
   %determine activity at next time step
   next = act; %reshape(spont, r, c) + act;
   holder = find(ref > 0);  %turn off all units that are already refractory
   next(holder) = 0;
   if refperiod ~= 0
       holder = find(current >= threshold);
       next(holder) = 0;        %turn off all units in next time step that fired in current time step
   end
   holder = find(next >= threshold);
   next(holder) = 1;        %make next have binary values only
   holder = find(next < threshold);
   next(holder) = 0;
   
   %determine refractory units for next time step
   if refperiod ~= 0
       ref = ref -1;  %decrement old values
       holder = find(ref < 0);
       ref(holder) = 0;
       holder = find(next >= threshold);  %increment new values
       ref(holder) = refperiod;
   end
      
   %update current matrix and clear other matricies
   current = next;
   next = sparse(r,c);
   act = sparse(r,c);
   spont = sparse(r,c);
   TIMERASTER(:,i) = current(OutputUnits);
end


