function [probS, probR, dynamicRange, info, Hresp, Hcond]= ResponseProbability(stim, response)
%Takes stim and response from FeedForwardBranchingModel4 and converts them
%to a stim and response probability plots, respectively
%Note: we assume here that stim and response are arrays with same
%dimensions

%get sizes
[neurons, iterations] = size(response); %response is an array where each row gives the number of neurons stimulated, and 
                                        %each column gives the number of
                                        %neurons activated in response, for
                                        %each iteration

%convert them from array format to vector format 
S = zeros(1, (neurons*iterations));
R = zeros(1, (neurons*iterations));
for i=1:(neurons*iterations)
    S(i) = stim(i);
    R(i) = response(i);
end

%count how many times each stimulus, response occur in each vector
totalR = zeros(1, neurons+1);
totalS = zeros(1, neurons+1);
for i=1:neurons
    holder = find(R == i);
    totalR(i+1) = length(holder);
    
    holder = find(S == i);
    totalS(i+1) = length(holder);
end

%find sums so we can normalize them
probR = totalR/sum(sum(totalR));
probS = totalS/sum(sum(totalS));


%find response values demarcating 20% and 80% of distribution area for
%response; to calculate dynamic range. Plot it. 
cumulativeSum = zeros(1, length(probR));
cumulativeSum(1) = probR(1);
for i=2:length(probR)
    cumulativeSum(i) = cumulativeSum(i-1) + probR(i);
end

figure; plot(cumulativeSum);
ylabel('Cumulative probability', 'FontSize', 15); xlabel('Response, number of neurons', 'FontSize', 15);
lowerList = find(cumulativeSum > 0.20);
upperList = find(cumulativeSum < 0.80);

beg = lowerList(1);
fin = upperList(end); 

dynamicRange = fin - beg;

%plot the probability distributions (note that zero is never presented as a
%stimulus
figure; plot((0:neurons), probR, 'linewidth',1.5,'Color',[0 0 0]+0.05*1); hold on


%include cutoffs for dynamic range
line([beg beg], [0, max(probR)], 'linewidth',1,'Color',[0 0 0]+0.05*10);
line([fin fin], [0, max(probR)], 'linewidth',1,'Color',[0 0 0]+0.05*10);

ylabel('Probability(Response)', 'FontSize', 15); xlabel('Response, number of neurons', 'FontSize', 15);

%Get information, response entropy, conditional entropy
[info, Hresp, Hcond] = FindInformation(S, R, log2(neurons));

