function [AllChi, AllRho, BR] = SusceptibilityDemoFunction(neurons, layers, connects, timesteps, numSamples)
%Plots susceptibility in blue for different branching ratios. Also plots
%density of active sites in red. Uses a feedforward branching model.
%Uses FeedforwardBranchingModelFunction, SusceptibilityCalc

%Explanation of input parameters and representative sample values
%neurons = 50; %number of neurons in each layer
numStim = 1; %number of neurons stimulated in first layer
%layers = 25;  %number of layers in the feedforward network
%connects = 5; %number of connections each neuron projects into the next layer
%timesteps = 500; %number of timesteps the network is run for in producing the TIMERASTER
%numSamples = 50; %number of increments the branching ratio will be swept through

AllChi = zeros(numSamples, 1); 
AllRho = zeros(numSamples, 1); 
BR = zeros(numSamples, 1); 
for i=1:numSamples
    i
    sums = i * 0.1;
    BR(i) = sums;
    TIMERASTER = FeedForwardBranchingModelFunction(neurons, numStim, layers, connects, sums, timesteps);
    chi = SusceptibilityCalc(TIMERASTER);
    rho = sum(sum(TIMERASTER))/(timesteps * neurons); 
    AllChi(i) = chi; 
    AllRho(i) = rho;   
end

figure; plot(BR, AllChi/max(AllChi), 'b'); hold on  %normalized Chi here
plot(BR, AllRho, 'ro');
ylabel('Susceptibility', 'FontSize', 15); xlabel('Branching Ratio', 'FontSize', 15);
title("Rho in red, Chi in blue")

