function [rsequence] = remove(sequence, num)
%Takes a sequence of numbers (a vector arranged in ascending order) and removes the element 
%whose value is num.  It then concatenates the sequence to close the gap.  Thus, the removed sequence, 
%rsequence,will be one unit shorter in length than the original sequence (as long as num is in sequence).  
%Example: remove(bins, 4), where bins is [1 3 4 5 7 8 9], would produce rsequence=[1 3 5 7 8 9].


if isempty(sequence)
    rsequence = sequence;
else
    
   %transpose into column vector if not already one
   [rw, cl] = size(sequence);
   if cl > rw
       sequence = sequence';
       marker = 1;
   else 
       marker = 0;
   end

   %find the location of the element(s) to be removed
   [Y, ~] = find(sequence == num);
   if isempty(Y)
      Y = -1;
   end
   ls = length(sequence);


   if ls == 1							%cases where length of sequence is equal to one
      if num == sequence
         rsequence = [];
      else
         rsequence = sequence;
      end
   
   else									%cases where length of sequence is greater than one
      %Four cases for removal:
      %element is not in sequence (Y = -1)
      %element is at the beginning of the sequence
      %element is at the end of the sequence
      %element is somewhere in between the beginning and the end
      switch Y(1)
      case -1
         rsequence = sequence;
      case 1
         rsequence = sequence(2:ls);
      case ls
         rsequence = sequence(1:ls-1);
      otherwise
         rsequence = [sequence(1:Y-1); sequence(Y+1:ls)];
      end

   end
   if marker == 1  %transpose back if it wasn't a column vector
       sequence = sequence';
   end
end

