%IsingPlotterTriangle
%This script should be run right after you run IsingLoopTriangle so
%that the variables timesteps, r, numRuns and increment are still
%available. If you have already cleared them, then you can just reset them
%as follows (an example is given below; your numbers may have been different:
% r = 10; timesteps = 50002; numRuns = 30; increment = 0.25; 

%Note: these numbers (timesteps, numRuns, r) can be found in the name of the files they correspond to
%Just look at the file names in your Matlab work directory. For example: IsingTriangle_T350r20timesteps100002.
%The IsingTriangle means a triangular lattice (IsingSquare for a square lattice), T350 means T = 3.5, r20 means 20 x 20 lattice
%timesteps100002 means that many timesteps. 

%Create arrays for storing variables of interest
Chi2 = [];
Call = [];
DensityAll = [];
ARall = [];
Energy = [];
pointA = floor(0.80*timesteps); %do not take all timesteps, but chop off the beginning as there is a transient. 
pointB = timesteps;
k = 1;
for i=1:numRuns
    i
    TeeVals(i) = increment * i;
    fname = ['IsingTriangle_T' num2str(100*TeeVals(i)) 'r' num2str(r), 'timesteps' num2str(timesteps)];
    load(fname);
    
    Chi2 = [Chi2 var(DensityOfSites(pointA:pointB))];
    Energy = [Energy mean(Elog(pointA:pointB))];
    Call = [Call var(Elog(pointA:pointB))/(TeeVals(i))^2];
    DensityAll = [DensityAll abs(mean(DensityOfSites(pointA:pointB)- 0.5))];

    AvgR = [];
    for j=1:r
        N = reshape(CorrMat(j,:,:), r, []);
        R = cov(N');
        posList = [j:r 1:j-1];
        AvgR = [AvgR; R(j,posList)];
    end
    %J = find(AvgR == NaN);
    AR = sum(AvgR)/r;
    ARall = [ARall; AR];

end

%Plot figures 
figure; plot(TeeVals, Chi2, 'ko'); ylabel('Susceptibility', 'FontSize', 15); xlabel('Temperature', 'FontSize', 15);
figure; plot(TeeVals, Call, 'ko'); ylabel('Specific heat', 'FontSize', 15); xlabel('Temperature', 'FontSize', 15);
figure; plot(TeeVals, 2*DensityAll, 'ko'); ylabel('Magnetization per spin', 'FontSize', 15); xlabel('Temperature', 'FontSize', 15);
figure; plot(TeeVals, Energy, 'ko'); ylabel('Energy', 'FontSize', 15); xlabel('Temperature', 'FontSize', 15);

