function [sizeDist, durationDist, SvsT, Events] = AvalancheAnalysis(TR)
%Function to plot avalanche distributions for size (S), duration (T) and 
%average size for a given duration (S vs. T). Gives as output sizeDist,
%durationDist, SvsT. Each of these variables has in the first row the
%values that go along the x-axis, and in the second row the values that go
%along the y-axis. 
%Assumes you already have the data in TIMERASTER format. If you do not, 
%use ASDFToSparse: [TIMERASTER, binunit] = ASDFToSparse(ASDF);


%First, extract avalanche statistics
[Events, Locations, IEI, Sizes, Runtimes] = runStats(TR);

%Second, plot avalanche distributions and extract output variables
%Duration distribution
for i=1:length(Events)
   durations(i) = length(Events{i});
end
for i=1:max(durations)
   dummy = find(durations == i);
   dist(i) = length(dummy);
end
y = 1:length(dist);
figure; plot(log10(y),log10(dist/sum(dist)),'k o'); ylabel('Log(Prob(Avalanche duration))', 'FontSize', 15); xlabel('Log(Avalanche duration)', 'FontSize', 15);
durationDist(1, :) = y;
durationDist(2, :) = (dist/sum(dist));
%lengthdist = [y; dist];


%Size distribution
clear dist
dist = sparse(1, max(Sizes));
for i=1:max(Sizes)
   dummy = find(Sizes == i);
   dist(i) = length(dummy);
end
x = 1:max(Sizes);
figure;
plot(log10(x),log10(dist/sum(dist)),'k o'); ylabel('Log(Prob(Avalanche size))', 'FontSize', 15); xlabel('Log(Avalanche size)', 'FontSize', 15);
sizeDist(1, :) = x;
sizeDist(2, :) = (dist/sum(dist));
%areadist = [x; dist];

%Average size for a given duration: S vs T 
for i=1:max(durations)
    dummy = find(durations == i);
    AvgSize(i) = sum(Sizes(dummy))/length(dummy);
end
figure; 
plot(log10(y), log10(AvgSize),'k o');
ylabel('Log(Avg. Avalanche size)', 'FontSize', 15); xlabel('Log(Avalanche duration)', 'FontSize', 15);
SvsT(1, :) = y;
SvsT(2,:) = AvgSize; 





    

