function [Events, Locations, IEI, Sizes, Runtimes] = runStats(TR)
%runStats- to create arrays Events and Locations, which will be helpful in compiling 
%statistics 
%The output, Events, is a cell array containing the number of electrodes
%showing activity above threshold at a given time step. The other output, Locations,
%is a cell array containing the locations of all the electrodes that were active at
%the start of a run (all initiation sites).

%Create variables
pointer = 1;
Events = [];
Locations = [];
Runtimes = [];
IEI = [];     %Inter Event Interval
Sizes = [];
counter = 1;
[r c] = size(TR);
b = ones(1,r)*TR;
I = find(b ~= 0);        %find locations where there is activity in TIMERASTER. These are the runs. Remember that many amplitudes are negative.

trigs = [];        
crossings = [];

%get first index (=trigs) from each period of activity.  These are the starts of runs.   
        switch length(I)
   	    case 0                              % if no activity do nothing
   	    case 1
      	    crossings(1) = I(1);            %the first element, if it exists, is always the start of a run. 
   	    case 2
      	    crossings(1) = I(1);     
      	    if (I(2)-I(1)) > 1
         	    crossings(2) = I(2);
            end
   	    otherwise
      	    crossings(1) = I(1);
            JumpIndx = find(diff(I)>1)+1;       
            crossings(JumpIndx)= I(JumpIndx);
        end
        trigs = crossings(find(crossings > 0));

%tic;
for i=1:length(trigs) 
   if i < length(trigs)
      IEI = [IEI (trigs(i+1) - trigs(i))];
   end
   holdera = [];
   holderb = [];
   Locations{counter} = find(full(TR(:, trigs(i)))> 0);  %gives locations of initiation sites only, not all elects
   pointer = trigs(i);
   while (pointer <= c) && (sum(full(TR(:, pointer))) ~= 0)
     holdera = [holdera pointer]; 
     holderb = [holderb sum(full(TR(:, pointer)))]; 
     pointer = pointer + 1;
   end
   Runtimes{counter} = holdera;
   Events{counter} = holderb;
   Sizes = [Sizes sum(Events{counter})];
   counter = counter + 1;
end


