function [BRest] = BPF_estimator(TR)
%Function to estimate the branching ratio from a TIMERASTER output of BranchingProcessFunction

%This function finds all the times I in the TIMERASTER where the first node in the
%binary tree was activated. This first node is always in row 1. This is the
%single ancestor node. 
%The nodes descended from that will be in rows 2 and 3 of the TIMERASTER
%The sum of all these active nodes, divided by the number of times the
%ancestor was activated, will give an estimate of the branching ratio for
%this binary tree network. 

I = find(TR(1, :) == 1);
BRest = sum(sum(TR(2:3, I+1)))/length(I);
BRest = full(BRest); 