function [stim, resp] = BP_infoPrep(Layers, stimLayer, respLayer, iterations, TIMERASTER)
%Prepares output of BranchingProcessFunction for information calculation. Stim will be taken
%from the second layer (only use stimLayer = 2 in this version) and response can be taken from
%any subsequent layer, but a good choice is respLayer = 4). If you have
%more interving layers, then the information transmitted declines. 
%Feed this the same parameter values that were associated with
%BranchingProcessFunction for Layers, iterations, and TIMERASTER


if stimLayer >= Layers
    error('stimLayer must be at least one layer before the end of the network');
end
if stimLayer <= 1
    error('stimLayer cannot be the first layer of the network');
end

if respLayer == stimLayer
    error('respLayer must be at least one layer larger than stimLayer');
end
if respLayer <= 2
    error('respLayer cannot be the first or second layer of the network');
end

%create list of nodes by layer; in layer i, NodesByLayer{i} lists only
%those nodes in that layer
for i=1:respLayer
    NodesByLayer{i} = [2^(i-1):((2^i)-1)]; %for second layer, nodes 2, 3. For third layer, nodes 4, 5, 6, 7, etc.
end

stim = zeros(iterations, 1);
StimRows = NodesByLayer{stimLayer};
resp = zeros(iterations, 1); 
RespRows = NodesByLayer{respLayer};
len = 2^(respLayer - 1);
a = len/2;
b = len/2 + 1;
for i=1:iterations
    
    %gather all the stim configurations from layer 2
    col = 2 + (i-1)*(Layers+1);
    stim(i) = bin2dec2(TIMERASTER(StimRows, col));

    %coarse-grain the responses, as they have more neurons
    holder = TIMERASTER(RespRows, col+(respLayer - stimLayer));
    bit1 = round((sum(holder(1:a))/a) + (randn*1e-2));    %small random number breaks ties
    bit2 = round((sum(holder(b:len))/a) + (randn*1e-2));  %small random number breaks ties
    resp(i) = bin2dec2([bit1 bit2]); 

end




