%PspontInfoLoop
%Plots mutual information against branching ratio for different values of
%Pspont. 
%Calls BranchingProcessFunction, BP_infoPrep, FindInformation

tic; 
iterations = 10000;
Layers = 4;
stimLayer = 2; 
respLayer = 4; 
dim = 2; 
Ps = [0, 0.01, 0.1, 0.25];
MItotal = [];
%loop through different values of Ps
for j = 1:length(Ps)
    %j
    for i=1:20 %loop through different values of Branching Ratio
        %i
        P = 0.05*i;
        [TIMERASTER] = BranchingProcessFunction(Layers, P*2, iterations, Ps(j));
        [stim, resp] = BP_infoPrep(Layers, stimLayer, respLayer, iterations, TIMERASTER);
        [info, Hresp, Hcond] = FindInformation(stim, resp, dim);
        INFO(i) = info;
    end
    MItotal = [MItotal; INFO];
end


%make plots
BR = 0.05:0.05:1.0;
figure; plot(BR, MItotal(1, :), 'k'); ylabel('MI (bits)', 'FontSize', 15); xlabel('Branching ratio', 'FontSize', 15); %black curve for Pspont = 0
hold on
plot(BR, MItotal(2,:), 'b'); %blue curve for Pspont = 0.01
plot(BR, MItotal(3,:), 'g'); %green curve for Pspont = 0.1
plot(BR, MItotal(4,:), 'r'); %red curve for Pspont = 0.25
ylim([0 1]);
legend('Pspont=0','Pspont=0.01','Pspont=0.1','Pspont=0.25','Location','northwest');

toc
