%PspontPhaseLoop
%Makes phase plot for different values of Pspont
%Plot consists of fraction of active nodes plotted against branching ratio.
%Only takes fraction of activity in last layer, not in the entire network. 

tic; %time it to see how long it takes to run 

%initialize some parameters
iterations = 10000;
Layers = 7;
Ps = [0, 0.01, 0.1 0.25]; %, 0.25, 1.0];
P = 0:0.05:1; 

%set up way to index nodes by layer
for i=1:Layers
    NodesByLayer{i} = [2^(i-1):((2^i)-1)]; %for second layer, nodes 2, 3. For third layer, nodes 4, 5, 6, 7, etc.
end


Rho = zeros(length(Ps), length(P));
indices = Layers:(Layers+1):iterations*(Layers+1)

%loop through different values of Pspont
for i = 1:length(Ps)
    for j=1:length(P) %loop through different values of branching ratio, which is P(j)*2 in binary tree network
        j
        [TIMERASTER] = BranchingProcessFunction(Layers, P(j)*2, iterations, Ps(i));
        [r c] = size(TIMERASTER); 
        Rho(i, j) = (sum(sum(TIMERASTER(NodesByLayer{Layers}, indices))))/(length(indices)*length(NodesByLayer{Layers})); 
    end 
end

%make plots
figure; plot(2*P, Rho(1,:), 'k'); ylabel('Rho', 'FontSize', 15); xlabel('Branching Ratio', 'FontSize', 15); hold on
for i=2:length(Ps)
    plot(2*P, Rho(i,:), 'r'); 
end


toc
